KloudBuster Report

### KloudBuster Storage Test Report

#### {{current_mode_description}}

##### {{modes[current_mode_name]["title"]}} {{current_title}} ({{storage_target[from_outside.storage_target]}})

###### {{current_mode["y_axis"]}}Latency(ms)

{{row.total_client_vms}} | {{row.block_size}}b | {{row.iodepth}} | {{row.rate_iops}} | {{row.read_iops}} | {{row.write_iops}} | {{row.rate}} KB/s | {{row.read_bw}} KB/s | {{row.write_bw}} KB/s

### KloudBuster HTTP Test Configuration

{{from_outside_config}}